Power 2011 atlas


Notes
-----
264 ROIs obtained by meta-analysis.


Content
-------
    :'rois': Coordinates of ROIs in MNI space.


References
----------
Power, Jonathan D., et al. "Functional network organization of the human
brain." Neuron 72.4 (2011): 665-678.
